@@ -6,7 +6,7 @@ from uuid import UUID, uuid4
 
 from ujson import loads, dumps
 
-from holmes.models import Review, Page
+from holmes.models import Review, Page, Key
 from holmes.handlers import BaseHandler
 
 
@@ -28,16 +28,10 @@ class ReviewHandler(BaseReviewHandler):
             self.set_status(404, 'Review with uuid of %s not found!' % review_uuid)
             return
 
-        if review.completed_date:
-            completed_data_iso = review.completed_date.isoformat()
-        else:
-            completed_data_iso = None
-
-        result = review.to_dict()
+        result = review.to_dict(self.application.fact_definitions, self.application.violation_definitions)
         result.update({
             'violationPoints': review.get_violation_points(),
             'violationCount': review.violation_count,
-            'completedDateISO': completed_data_iso
         })
 
         self.write_json(result)
@@ -62,7 +56,7 @@ class ReviewHandler(BaseReviewHandler):
             page=page,
             is_active=True,
             is_complete=False,
-            completed_date=datetime.now(),
+            completed_date=datetime.utcnow(),
             uuid=uuid4(),
         )
 
@@ -70,11 +64,15 @@ class ReviewHandler(BaseReviewHandler):
         self.db.flush()
 
         for fact in review_data['facts']:
-            review.add_fact(fact['key'], fact['value'], fact['title'], fact['unit'])
+            key = Key.get_or_create(self.db, fact['key'])
+            review.add_fact(key, fact['value'])
+
         self.db.flush()
 
         for violation in review_data['violations']:
-            review.add_violation(violation['key'], violation['title'], violation['description'], violation['points'])
+            key = Key.get_or_create(self.db, violation['key'])
+            review.add_violation(key, violation['value'], violation['points'])
+
         self.db.flush()
 
         review.is_complete = True
@@ -129,10 +127,9 @@ class LastReviewsHandler(BaseReviewHandler):
 
         reviews_json = []
         for review in reviews:
-            review_dict = review.to_dict()
+            review_dict = review.to_dict(self.application.fact_definitions, self.application.violation_definitions)
             data = {
                 'violationCount': review.violation_count,
-                'completedDateISO': review.completed_date.isoformat()
             }
             review_dict.update(data)
             reviews_json.append(review_dict)
