@@ -28,6 +28,7 @@ from holmes.handlers.search import (
 )
 from holmes.handlers.bus import EventBusHandler
 from holmes.event_bus import EventBus, NoOpEventBus
+from holmes.utils import load_classes
 
 
 def main():
@@ -36,6 +37,20 @@ def main():
 
 
 class HolmesApiServer(Server):
+    def __init__(self, db=None, debug=None, *args, **kw):
+        super(HolmesApiServer, self).__init__(*args, **kw)
+
+        self.force_debug = debug
+        self.db = db
+
+    def initialize_app(self, *args, **kw):
+        super(HolmesApiServer, self).initialize_app(*args, **kw)
+
+        self.application.db = None
+
+        if self.force_debug is not None:
+            self.debug = self.force_debug
+
     def get_handlers(self):
         handlers = [
             (r'/most-common-violations/?', MostCommonViolationsHandler),
@@ -67,15 +82,45 @@ class HolmesApiServer(Server):
         ]
 
     def after_start(self, io_loop):
-        self.application.db = self.application.get_sqlalchemy_session()
+        if self.db is not None:
+            self.application.db = self.db
+        else:
+            self.application.db = self.application.get_sqlalchemy_session()
+
+        if self.debug:
+            import sqltap
+            sqltap.start()
+
+        self.application.facters = self._load_facters()
+        self.application.validators = self._load_validators()
+
+        self.application.fact_definitions = {}
+        self.application.violation_definitions = {}
+
+        for facter in self.application.facters:
+            self.application.fact_definitions.update(facter.get_fact_definitions())
+
+        for validator in self.application.validators:
+            self.application.violation_definitions.update(validator.get_violation_definitions())
 
         self.application.event_bus = NoOpEventBus(self.application)
         self.application.http_client = AsyncHTTPClient(io_loop=io_loop)
         self.connect_pub_sub(io_loop)
 
+    def _load_validators(self):
+        return load_classes(default=self.config.VALIDATORS)
+
+    def _load_facters(self):
+        return load_classes(default=self.config.FACTERS)
+
     def before_end(self, io_loop):
         self.application.db.remove()
 
+        if self.debug:
+            import sqltap
+            statistics = sqltap.collect()
+            sqltap.report(statistics, "report.html")
+
     def connect_pub_sub(self, io_loop):
         host = self.application.config.get('REDISHOST')
         port = self.application.config.get('REDISPORT')
